vfbLib.compilers.base.BaseCompiler
==================================

.. currentmodule:: vfbLib.compilers.base

.. autoclass:: BaseCompiler
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BaseCompiler.__init__
      ~BaseCompiler.compile
      ~BaseCompiler.compile_hex
      ~BaseCompiler.merge
      ~BaseCompiler.write_bytes
      ~BaseCompiler.write_double
      ~BaseCompiler.write_doubles
      ~BaseCompiler.write_float
      ~BaseCompiler.write_floats
      ~BaseCompiler.write_int16
      ~BaseCompiler.write_int32
      ~BaseCompiler.write_str
      ~BaseCompiler.write_uint16
      ~BaseCompiler.write_uint32
      ~BaseCompiler.write_uint8
      ~BaseCompiler.write_value
   
   

   
   
   